==> dl.php?src=linea21_2_0_0.zip: linea21/languages/es/lang_scale.utf-8.php <==
<?php
/**
 * @package linea21\languages\es
 * @author $Author$ - Marta Rada Arias, Alejandro Villar Fernández (www.icane.es) & linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


/*	nommage des modules
 *  	*/
$lang['scale']['name']="escala";
$lang['scale']['confirm_add'] = "escala añadida correctamente";
$lang['scale']['confirm_mod'] = "escala actualizada correctamente";
$lang['scale']['confirm_sup'] ="escala eliminada correctamente";


/*	nommage rubrique module
 *  	*/
$lang['scale']['add']= "Añadir una nueva ".$lang['scale']['name'];
$lang['scale']['mod']= "Editar ".$lang['scale']['name'];
$lang['scale']['sup']= "Eliminar ".$lang['scale']['name'];
$lang['scale']['det']= ucfirst($lang['scale']['name']). " detalles";
$lang['scale']['list']= "Ver escalas";


/*	nommage rubrique add / mod /det
 *  	*/
$lang['scale']['add_title']="Añadir valores a la nueva ".$lang['scale']['name'];



/*	nommage rubrique sup
 *  	*/
$lang['scale']['sup_massd']= "¿Desea eliminar las sub-escalas asociadas a la escala actual?";
$lang['scale']['sup_massm']= "¿Desea transferir todas estas sub-escalas a otra escala?"; 
$lang['scale']['sup_transfert']= "Transferir escala";
/*	nommage élément rubrique
 *  	*/
$lang['scale']['denomination']="nombre";
$lang['scale']['surface']="superficie";
$lang['scale']['population']="población";
$lang['scale']['cin']="<abbr title=\"Número oficial de comunidad\">NOC</abbr>";
$lang['scale']['root']="escala superior";
$lang['scale']['comment']="comentarios relacionados con la ".$lang['scale']['name'];


/*	nommage quickbox
 *  	*/
$lang['scale']['qb_titleadd']=" escalas agregadas recientemente";
$lang['scale']['qb_titlemod']=" escalas modificadas recientemente";
$lang['scale']['qb_titlesup']=" escalas eliminadas recientemente";


/*	divers
 *  	*/
$lang['scale']['select_choice']="-- Seleccionar de la lista --";


/*	messages
 *  	*/
$lang['scale']['object_notdenomination']="El nombre es requerido";
$lang['scale']['object_notnumsurface']="La superficie debe tener un valor numérico";
$lang['scale']['object_notnuminhabitants']="La población debe tener un valor entero";
$lang['scale']['object_notroot']="La escala superior es requerida";
$lang['scale']['sup_nomethod']="El método de eliminación es requerido";
$lang['scale']['sup_noscale']="La escala transferida es requerida";
$lang['scale']['sup_scale_info1']="¡Atención, si transfiere esta escala se transferirán también las sub-escalas, proyectos, noticias, publicaciones e indicadores asociados con ella!";
$lang['scale']['sup_scale_info2']="¡Atención, si elimina esta escala se eliminarán también las sub-escalas, proyectos, noticias, publicaciones e indicadores asociados con ella!";


/*	rubrique d'aide
 *  	*/
$lang['scale']['help_add1']="Para añadir una nueva escala, inserte la información requerida en el formulario.";
//$lang['scale']['help_add2']="Debe especificar la escala superior.";
$lang['scale']['help_add3']="Completado el cuestionario, revise los valores en el resumen.";
$lang['scale']['help_add4']='Validado el resumen, haga click en "revisar valores" si desea realizar cambios.';

$lang['scale']['help_list1']="Para mas información haga click en el nombre de la escala.";
$lang['scale']['help_list2']="Para eliminar la escala, haga click en el icono 'eliminar escala'.";
$lang['scale']['help_list3']="Para editar la escala, haga click en el icono 'editar escala'.";
$lang['scale']['help_list4']='Para añadir una nueva escala, haga click en el icono "añadir nueva escala".';
$lang['scale']['help_list5']="Si desea realizar búsquedas dentro del módulo 'escalas', haga click en 'buscar'.";

$lang['scale']['help_mod1']="Para editar la escala, inserte la información requerida en el formulario.";
$lang['scale']['help_mod2']="Completado el cuestionario, revise los valores en el resumen.";
$lang['scale']['help_mod3']="Validado el resumen, haga click en 'revisar valores' si desea realizar cambios.";

$lang['scale']['help_det1']="Para ver la información referida a la escala superior, haga click en el titulo de dicha escala.";
$lang['scale']['help_det2']="Para eliminar la escala, haga click en el icono 'eliminar escala'.";
$lang['scale']['help_det3']="Para editar la escala, haga click en el icono 'editar escala'.";

$lang['scale']['help_sup1']="Seleccione el método de eliminación para realizar la operación.";
$lang['scale']['help_sup2']="Por razones de seguridad, por favor introduzca el código de seguridad";
$lang['scale']['help_sup3']="Atención, si elimina la escala pueden producirse modificaciones en toda la aplicación; se recomienda que este proceso sea realizado únicamente por expertos.";
?>

==> dl.php?src=linea21_2_8_0.zip: linea21/languages/es/lang_scale.utf-8.php <==
<?php
/**
 * @package linea21\languages\es
 * @author $Author$ - Marta Rada Arias, Alejandro Villar Fernández (www.icane.es) & linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


/*	nommage des modules
 *  	*/
$lang['scale']['name']="escala";
$lang['scale']['confirm_add'] = "escala añadida correctamente";
$lang['scale']['confirm_mod'] = "escala actualizada correctamente";
$lang['scale']['confirm_sup'] ="escala eliminada correctamente";


/*	nommage rubrique module
 *  	*/
$lang['scale']['add']= "Añadir una nueva ".$lang['scale']['name'];
$lang['scale']['mod']= "Editar ".$lang['scale']['name'];
$lang['scale']['sup']= "Eliminar ".$lang['scale']['name'];
$lang['scale']['det']= ucfirst($lang['scale']['name']). " detalles";
$lang['scale']['list']= "Ver escalas";


/*	nommage rubrique add / mod /det
 *  	*/
$lang['scale']['add_title']="Añadir valores a la nueva ".$lang['scale']['name'];



/*	nommage rubrique sup
 *  	*/
$lang['scale']['sup_massd']= "¿Desea eliminar las sub-escalas asociadas a la escala actual?";
$lang['scale']['sup_massm']= "¿Desea transferir todas estas sub-escalas a otra escala?"; 
$lang['scale']['sup_transfert']= "Transferir escala";
/*	nommage élément rubrique
 *  	*/
$lang['scale']['denomination']="nombre";
$lang['scale']['surface']="superficie";
$lang['scale']['population']="población";
$lang['scale']['cin']="<abbr title=\"Número oficial de comunidad\">NOC</abbr>";
$lang['scale']['root']="escala superior";
$lang['scale']['comment']="comentarios relacionados con la ".$lang['scale']['name'];


/*	nommage quickbox
 *  	*/
$lang['scale']['qb_titleadd']=" escalas agregadas recientemente";
$lang['scale']['qb_titlemod']=" escalas modificadas recientemente";
$lang['scale']['qb_titlesup']=" escalas eliminadas recientemente";


/*	divers
 *  	*/
$lang['scale']['select_choice']="-- Seleccionar de la lista --";


/*	messages
 *  	*/
$lang['scale']['object_notdenomination']="El nombre es requerido";
$lang['scale']['object_notnumsurface']="La superficie debe tener un valor numérico";
$lang['scale']['object_notnuminhabitants']="La población debe tener un valor entero";
$lang['scale']['object_notroot']="La escala superior es requerida";
$lang['scale']['sup_nomethod']="El método de eliminación es requerido";
$lang['scale']['sup_noscale']="La escala transferida es requerida";
$lang['scale']['sup_scale_info1']="¡Atención, si transfiere esta escala se transferirán también las sub-escalas, proyectos, noticias, publicaciones e indicadores asociados con ella!";
$lang['scale']['sup_scale_info2']="¡Atención, si elimina esta escala se eliminarán también las sub-escalas, proyectos, noticias, publicaciones e indicadores asociados con ella!";


/*	rubrique d'aide
 *  	*/
$lang['scale']['help_add1']="Para añadir una nueva escala, inserte la información requerida en el formulario.";
//$lang['scale']['help_add2']="Debe especificar la escala superior.";
$lang['scale']['help_add3']="Completado el cuestionario, revise los valores en el resumen.";
$lang['scale']['help_add4']='Validado el resumen, haga clic en "revisar valores" si desea realizar cambios.';

$lang['scale']['help_list1']="Para mas información haga clic en el nombre de la escala.";
$lang['scale']['help_list2']="Para eliminar la escala, haga clic en el icono 'eliminar escala'.";
$lang['scale']['help_list3']="Para editar la escala, haga clic en el icono 'editar escala'.";
$lang['scale']['help_list4']='Para añadir una nueva escala, haga clic en el icono "añadir nueva escala".';
$lang['scale']['help_list5']="Si desea realizar búsquedas dentro del módulo 'escalas', haga clic en 'buscar'.";

$lang['scale']['help_mod1']="Para editar la escala, inserte la información requerida en el formulario.";
$lang['scale']['help_mod2']="Completado el cuestionario, revise los valores en el resumen.";
$lang['scale']['help_mod3']="Validado el resumen, haga clic en 'revisar valores' si desea realizar cambios.";

$lang['scale']['help_det1']="Para ver la información referida a la escala superior, haga clic en el titulo de dicha escala.";
$lang['scale']['help_det2']="Para eliminar la escala, haga clic en el icono 'eliminar escala'.";
$lang['scale']['help_det3']="Para editar la escala, haga clic en el icono 'editar escala'.";

$lang['scale']['help_sup1']="Seleccione el método de eliminación para realizar la operación.";
$lang['scale']['help_sup2']="Por razones de seguridad, por favor introduzca el código de seguridad";
$lang['scale']['help_sup3']="Atención, si elimina la escala pueden producirse modificaciones en toda la aplicación; se recomienda que este proceso sea realizado únicamente por expertos.";
?>
